OC.L10N.register(
    "lib",
    {
    "Help" : "உதவி",
    "Personal" : "தனிப்பட்ட",
    "Users" : "பயனாளர்",
    "Admin" : "நிர்வாகம்",
    "today" : "இன்று",
    "yesterday" : "நேற்று",
    "last month" : "கடந்த மாதம்",
    "last year" : "கடந்த வருடம்",
    "seconds ago" : "செக்கன்களுக்கு முன்",
    "web services under your control" : "வலைய சேவைகள் உங்களுடைய கட்டுப்பாட்டின் கீழ் உள்ளது",
    "Application is not enabled" : "செயலி இயலுமைப்படுத்தப்படவில்லை",
    "Authentication error" : "அத்தாட்சிப்படுத்தலில் வழு",
    "Token expired. Please reload page." : "அடையாளவில்லை காலாவதியாகிவிட்டது. தயவுசெய்து பக்கத்தை மீள் ஏற்றுக.",
    "Could not find category \"%s\"" : "பிரிவு \"%s\" ஐ கண்டுப்பிடிக்க முடியவில்லை"
},
"nplurals=2; plural=(n != 1);");
